Module msg

Structs

DataverseResponse
DataverseResponse
InstantiateMsg
InstantiateMsg is used to initialize a new instance of the dataverse.
TripleStoreConfig
TripleStoreConfig
TripleStoreLimitsInput
TripleStoreLimitsInput

Enums

ExecuteMsg
ExecuteMsg defines the set of possible actions that can be performed on the dataverse.
QueryMsg
QueryMsg defines the set of possible queries that can be made to retrieve information about the dataverse.
RdfDatasetFormat
RdfDatasetFormat