pub struct TripleStoreConfig {
pub code_id: Uint64,
pub limits: TripleStoreLimitsInput,
}Expand description
TripleStoreConfig
TripleStoreConfig represents the configuration related to the management of the triple store.
Fields
code_id: Uint64The code id that will be used to instantiate the triple store contract in which to store dataverse semantic data. It must implement the cognitarium interface.
limits: TripleStoreLimitsInputLimitations regarding triple store usage.