axone_dataverse

Module msg

Structs

Enums

  • ExecuteMsg defines the set of possible actions that can be performed on the dataverse.
  • QueryMsg defines the set of possible queries that can be made to retrieve information about the dataverse.
  • RdfDatasetFormat