Structs
- DataverseResponse
InstantiateMsgis used to initialize a new instance of the dataverse.- TripleStoreConfig
- TripleStoreLimitsInput
Enums
ExecuteMsgdefines the set of possible actions that can be performed on the dataverse.QueryMsgdefines the set of possible queries that can be made to retrieve information about the dataverse.- RdfDatasetFormat