pub struct TripleStoreLimitsInput {
pub max_triple_count: Option<Uint128>,
pub max_byte_size: Option<Uint128>,
pub max_triple_byte_size: Option<Uint128>,
pub max_query_limit: Option<u32>,
pub max_query_variable_count: Option<u32>,
pub max_insert_data_byte_size: Option<Uint128>,
pub max_insert_data_triple_count: Option<Uint128>,
}Expand description
TripleStoreLimitsInput
Contains requested limitations regarding store usages.
Fields
max_triple_count: Option<Uint128>The maximum number of triples the store can contain. Default to Uint128::MAX if not set, which can be considered as no limit.
max_byte_size: Option<Uint128>The maximum number of bytes the store can contain. The size of a triple is counted as the sum of the size of its subject, predicate and object, including the size of data types and language tags if any. Default to Uint128::MAX if not set, which can be considered as no limit.
max_triple_byte_size: Option<Uint128>The maximum number of bytes the store can contain for a single triple. The size of a triple is counted as the sum of the size of its subject, predicate and object, including the size of data types and language tags if any. The limit is used to prevent storing very large triples, especially literals. Default to Uint128::MAX if not set, which can be considered as no limit.
max_query_limit: Option<u32>The maximum limit of a query, i.e. the maximum number of triples returned by a select query. Default to 30 if not set.
max_query_variable_count: Option<u32>The maximum number of variables a query can select. Default to 30 if not set.
max_insert_data_byte_size: Option<Uint128>The maximum number of bytes an insert data query can contain. Default to Uint128::MAX if not set, which can be considered as no limit.
max_insert_data_triple_count: Option<Uint128>The maximum number of triples an insert data query can contain (after parsing). Default to Uint128::MAX if not set, which can be considered as no limit.